@@ -1,8 +1,9 @@
+package
+Net::OpenID::Association;
 use strict;
 use Carp ();
 
 ############################################################################
-package Net::OpenID::Association;
 use fields (
             'server',    # author-identity identity server endpoint
             'secret',    # the secret for this association
@@ -12,6 +13,7 @@ use fields (
             );
 
 use Storable ();
+use Crypt::DH::GMP 0.0.5;
 use Digest::SHA1 qw(sha1);
 
 sub new {
@@ -215,7 +217,7 @@ sub invalidate_handle {
 }
 
 sub _default_dh {
-    my $dh = Crypt::DH->new;
+    my $dh = Crypt::DH::GMP->new;
     $dh->p("155172898181473697471232257763715539915724801966915404479707795314057629378541917580651227423698188993727816152646631438561595825688188889951272158842675419950341258706556549803580104870537681476726513255747040765857479291291572334510643245094715007229621094194349783925984760375594985848253359305585439638443");
     $dh->g("2");
     $dh->generate_keys;
